@@ -64,9 +64,11 @@ from scs_core.comms.uds_writer import UDSWriter
 from scs_core.data.publication import Publication
 
 from scs_core.sys.filesystem import Filesystem
-from scs_host.sys.host import Host
 from scs_core.sys.system_id import SystemID
 
+from scs_host.comms.domain_socket import DomainSocket
+from scs_host.sys.host import Host
+
 
 # --------------------------------------------------------------------------------------------------------------------
 
@@ -107,7 +109,7 @@ if __name__ == '__main__':
             exit(1)
 
         # comms...
-        source = UDSReader(cmd.uds_pub)
+        source = UDSReader(DomainSocket, cmd.uds_pub)
 
         if cmd.verbose:
             print("aws_mqtt_client: %s" % source, file=sys.stderr)
@@ -142,7 +144,7 @@ if __name__ == '__main__':
             topic = project.channel_path(cmd.channel, system_id)
 
             # subscriber...
-            sub_comms = UDSWriter(cmd.channel_uds)
+            sub_comms = UDSWriter(DomainSocket, cmd.channel_uds)
 
             handler = AWSMQTTSubscriptionHandler(reporter, comms=sub_comms,
                                                  wrap=cmd.wrap, timed=cmd.timed, echo=cmd.echo)
@@ -151,7 +153,7 @@ if __name__ == '__main__':
 
         else:
             for subscription in cmd.subscriptions:
-                sub_comms = UDSWriter(subscription.address)
+                sub_comms = UDSWriter(DomainSocket, subscription.address)
 
                 # subscriber...
                 handler = AWSMQTTSubscriptionHandler(reporter, comms=sub_comms,
